@@ -229,8 +229,8 @@ void KanjiBrowserView::setupView(   KanjiBrowser *parent
 {
   if( kanji.isEmpty() || kanjiGrades.isEmpty() || strokeCount.isEmpty() )
   {
-    qDebug() << "One or more of our lists are empty (kanji, grades, strokes)." << endl;
-    qDebug() << "Could not load the view properly." << endl;
+    qDebug() << "One or more of our lists are empty (kanji, grades, strokes).";
+    qDebug() << "Could not load the view properly.";
     KMessageBox::error( this, i18n( "Could not load the necessary kanji information." ) );
     return;
   }
@@ -267,8 +267,16 @@ void KanjiBrowserView::setupView(   KanjiBrowser *parent
     _strokes->addItem( i18np( "%1 stroke", "%1 strokes", stroke ) );
   }
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
   connect(_grades, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &KanjiBrowserView::changeGrade);
+#else
+  connect(_grades, static_cast<void (KComboBox::*)(int, const QString &)>(&KComboBox::currentIndexChanged) , this, &KanjiBrowserView::changeGrade);
+#endif
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
   connect(_strokes, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &KanjiBrowserView::changeStrokeCount);
+#else
+  connect(_strokes, static_cast<void (KComboBox::*)(int, const QString &)>(&KComboBox::currentIndexChanged) , this, &KanjiBrowserView::changeStrokeCount);
+#endif
   connect(_kanjiList, &QListWidget::itemClicked, this, &KanjiBrowserView::searchKanji);
   connect(_kanjiList, &QListWidget::itemClicked, _goToKanjiInfo, &QAction::triggered);
   connect(goToKanjiList, &QAction::triggered, this, &KanjiBrowserView::changeToListPage);
@@ -282,7 +290,7 @@ void KanjiBrowserView::setupView(   KanjiBrowser *parent
   _strokes->setCurrentIndex( 1 );
   _strokes->setCurrentIndex( NoStrokeLimit );
 
-  qDebug() << "Initial setup succeeded!" << endl;
+  qDebug() << "Initial setup succeeded!";
 }
 
 void KanjiBrowserView::showKanjiInformation( const EntryKanjidic *kanji )
